//
//  EditBookController.m
//  TestDataManageer
//
//  Created by Akabeko on 11/11/05.
//  Copyright (c) 2011, Akabeko. All rights reserved.
//

#import "EditBookController.h"
#import "Book.h"

@interface EditBookController()
- (void)checkDone;
- (void)authorTextFieldEditingChanged:(id)sender;
- (void)titleTextFieldEditingChanged:(id)sender;
- (void)cancel:(id)sender;
- (void)done:(id)sender;
@end

@implementation EditBookController

@synthesize delegate, book;

#pragma mark - View lifecycle

/**
 *  View が読み込まれる時に発生します。
 */
- (void)viewDidLoad
{
	[super viewDidLoad];

	// 完了ボタン
    UIBarButtonItem* doneButton = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemDone target:self action:@selector( done: )];
    self.navigationItem.rightBarButtonItem = doneButton;
    [doneButton release];

	_titleLabel.text     = NSLocalizedString( @"BOOK_EDIT_LABEL_TITLE",     @"" );
	_authorLabel.text    = NSLocalizedString( @"BOOK_EDIT_LABEL_AUTHOR",    @"" );
	_copyrightLabel.text = NSLocalizedString( @"BOOK_EDIT_LABEL_COPYRIGHT", @"" );

	_titleTextField.delegate  = self;
	_authorTextField.delegate = self;
	
	[_authorTextField addTarget:self action:@selector( authorTextFieldEditingChanged: ) forControlEvents:UIControlEventEditingChanged];
	[_titleTextField  addTarget:self action:@selector( titleTextFieldEditingChanged:  ) forControlEvents:UIControlEventEditingChanged];
	
	if( self.book )
	{
		_titleTextField.text      = self.book.title;
		_authorTextField.text     = self.book.author;
		_copyrightDatePicker.date = self.book.copyright;
	}
	else
	{
		_titleTextField.placeholder  = NSLocalizedString( @"BOOK_EDIT_PROMPT_TITLE",  @"" );
		_authorTextField.placeholder = NSLocalizedString( @"BOOK_EDIT_PROMPT_AUTHOR", @"" );

		// キャンセル ボタン
		UIBarButtonItem* cancelButton = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemCancel target:self action:@selector( cancel: )];
		self.navigationItem.leftBarButtonItem = cancelButton;
		[cancelButton release];
	}

	[self checkDone];
}

/**
 * View が破棄される時に発生します。
 */
- (void)viewDidUnload
{
	self.book = nil;

	[_titleLabel          release]; _titleLabel          = nil;
	[_titleTextField      release]; _titleTextField      = nil;
	[_authorLabel         release]; _authorLabel         = nil;
	[_authorTextField     release]; _authorTextField     = nil;
	[_copyrightLabel      release]; _copyrightLabel      = nil;
	[_copyrightDatePicker release]; _copyrightDatePicker = nil;

	[super viewDidUnload];
}

/**
 * メモリを解放します。
 */
- (void)dealloc
{
	self.book = nil;

	[_titleLabel          release];
	[_titleTextField      release];
	[_authorLabel         release];
	[_authorTextField     release];
	[_copyrightLabel      release];
	[_copyrightDatePicker release];

	[super dealloc];
}

#pragma mark - UITextFieldDelegate methods

/**
 * テキストフィールドでリターンが押された時に発生します。
 *
 * @param textField テキスト フィールド。
 *
 * @return 操作を確定させる場合は YES。それ以外は NO。
 */
- (BOOL)textFieldShouldReturn:(UITextField *)textField
{
	[textField resignFirstResponder];
	return YES;
}

#pragma mark - Private methods

/**
 * 著者テキストフィールドで編集が完了した時に発生します。
 *
 * @param sender 送信者データ。
 */
- (void)authorTextFieldEditingChanged:(id)sender
{
	[self checkDone];
}

/**
 * 題名テキストフィールドで編集が完了した時に発生します。
 *
 * @param sender 送信者データ。
 */
- (void)titleTextFieldEditingChanged:(id)sender
{
	[self checkDone];
}

/**
 * 編集を完了できることをチェックします。
 */
- (void)checkDone
{
	self.navigationItem.rightBarButtonItem.enabled = ( _titleTextField.text.length > 0 && _authorTextField.text.length > 0 );
}

/**
 * キャンセル ボタンが押された時に発生します。
 *
 * @param sender 送信者データ。
 */
- (void)cancel:(id)sender
{	
	[self.delegate addBookDidFinish:nil];
}

/**
 * 完了ボタンが押された時に発生します。
 *
 * @param sender 送信者データ。
 */
- (void)done:(id)sender
{
	Book* newBook = [[[Book alloc] init] autorelease];
	newBook.bookId    = self.book.bookId;
	newBook.title     = _titleTextField.text;
	newBook.author    = _authorTextField.text;
	newBook.copyright = _copyrightDatePicker.date;

	if( self.book )
	{
		[self.delegate editBookDidFinish:self.book newBook:newBook];
	}
	else
	{
		[self.delegate addBookDidFinish:newBook];
	}
}

@end
